@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
@@ -32,7 +32,7 @@ from translate.storage import po
 logger = logging.getLogger(__name__)
 
 
-class ini2po:
+class ini2po(object):
     """Convert a .ini file to a .po file for handling the translation..."""
 
     def convert_store(self, input_store, duplicatestyle="msgctxt"):
@@ -111,7 +111,7 @@ def convertini(input_file, output_file, template_file, pot=False,
                                              duplicatestyle=duplicatestyle)
     if output_store.isempty():
         return 0
-    output_file.write(str(output_store))
+    output_store.serialize(output_file)
     return 1
 
 
@@ -122,6 +122,12 @@ def convertisl(input_file, output_file, template_file, pot=False,
 
 
 def main(argv=None):
+    import sys
+    if sys.version_info[0] == 3:
+        print("Translate Toolkit doesn't yet support converting from INI in "
+              "Python 3.")
+        sys.exit()
+
     from translate.convert import convert
     formats = {
         "ini": ("po", convertini), ("ini", "ini"): ("po", convertini),
