@@ -1,12 +1,11 @@
-#!/usr/bin/env python2
-
+import six
 from pytest import mark
 
 from translate.convert import html2po, po2html, test_convert
 from translate.misc import wStringIO
 
 
-class TestHTML2PO:
+class TestHTML2PO(object):
 
     def html2po(self, markup, includeuntagged=False, duplicatestyle="msgctxt", keepcomments=False):
         """Helper to convert html to po without a file."""
@@ -21,7 +20,7 @@ class TestHTML2PO:
         outputfile = wStringIO.StringIO()
         templatefile = wStringIO.StringIO(htmltemplate)
         assert po2html.converthtml(inputfile, outputfile, templatefile)
-        return outputfile.getvalue()
+        return outputfile.getvalue().decode('utf-8')
 
     def countunits(self, pofile, expected):
         """helper to check that we got the expected number of messages"""
@@ -36,9 +35,9 @@ class TestHTML2PO:
         """helper to validate a PO message"""
         if not pofile.units[0].isheader():
             unitnumber = unitnumber - 1
-        print('unit source: ' + pofile.units[unitnumber].source.encode('utf-8') + '|')
-        print('expected: ' + expected.encode('utf-8') + '|')
-        assert unicode(pofile.units[unitnumber].source) == unicode(expected)
+        print('unit source: ' + pofile.units[unitnumber].source + '|')
+        print('expected: ' + expected + '|')
+        assert six.text_type(pofile.units[unitnumber].source) == six.text_type(expected)
 
     def check_single(self, markup, itemtext):
         """checks that converting this markup produces a single element with value itemtext"""
@@ -298,7 +297,7 @@ years has helped to bridge the digital divide to a limited extent.</p> \r
 
     def test_encoding_latin1(self):
         """Convert HTML input in iso-8859-1 correctly to unicode."""
-        htmlsource = '''<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+        htmlsource = b'''<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
 <html><!-- InstanceBegin template="/Templates/masterpage.dwt" codeOutsideHTMLIsLocked="false" -->
 <head>
 <!-- InstanceBeginEditable name="doctitle" -->
@@ -366,7 +365,7 @@ years has helped to bridge the digital divide to a limited extent.</p> \r
         # Translate and convert back:
         pofile.units[2].target = 'Projekte'
         pofile.units[3].target = 'Tuisblad'
-        htmlresult = self.po2html(str(pofile), htmlsource).replace('\n', ' ').replace('= "', '="').replace('> <', '><')
+        htmlresult = self.po2html(bytes(pofile), htmlsource).replace('\n', ' ').replace('= "', '="').replace('> <', '><')
         snippet = '<td width="96%"><strong><font class="headingwhite">Projekte</font></strong></td>'
         assert snippet in htmlresult
         snippet = '<td width="96%"><a href="index.html">Tuisblad</a></td>'
@@ -420,7 +419,7 @@ ghi ?>'''
         pofile = self.html2po('<!-- comment outside block --><p><!-- a comment -->A paragraph<!-- with another comment -->.</p>', keepcomments=True)
         self.compareunit(pofile, 1, 'A paragraph.')
         notes = pofile.getunits()[-1].getnotes()
-        assert unicode(notes) == ' a comment \n with another comment '
+        assert six.text_type(notes) == ' a comment \n with another comment '
 
 
 class TestHTML2POCommand(test_convert.TestConvertCommand, TestHTML2PO):
