@@ -1,14 +1,11 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-from pytest import mark
-
 from translate.convert import prop2po, test_convert
 from translate.misc import wStringIO
 from translate.storage import po, properties
 
 
-class TestProp2PO:
+class TestProp2PO(object):
 
     def prop2po(self, propsource, proptemplate=None, personality="java"):
         """helper that converts .properties source to po source without requiring files"""
@@ -133,9 +130,9 @@ prefPanel-smime=Security'''
 prefPanel-smime=
 '''
         pofile = self.prop2po(propsource)
-        print(str(pofile))
+        print(bytes(pofile))
         #header comments:
-        assert "#. # Comment\n#. # commenty 2" in str(pofile)
+        assert b"#. # Comment\n#. # commenty 2" in bytes(pofile)
         pounit = self.singleelement(pofile)
         assert pounit.getnotes("developer") == "## @name GENERIC_ERROR\n## @loc none"
 
@@ -165,7 +162,7 @@ do=translate me
             assert pounit.getlocations() == ["credit"]
             assert pounit.getcontext() == "credit"
             assert 'msgctxt "credit"' in str(pounit)
-            assert "#. # comment" in str(pofile)
+            assert b"#. # comment" in bytes(pofile)
             assert pounit.source == ""
 
     def test_emptyproperty_translated(self):
@@ -211,14 +208,14 @@ do=translate me
         propsource = '''prop=value\n'''
 
         outputpo = self.prop2po(propsource, personality="mozilla")
-        assert "X-Accelerator-Marker" in str(outputpo)
-        assert "X-Merge-On" in str(outputpo)
+        assert b"X-Accelerator-Marker" in bytes(outputpo)
+        assert b"X-Merge-On" in bytes(outputpo)
 
         # Even though the gaia flavour inherrits from mozilla, it should not
         # get the header
         outputpo = self.prop2po(propsource, personality="gaia")
-        assert "X-Accelerator-Marker" not in str(outputpo)
-        assert "X-Merge-On" not in str(outputpo)
+        assert b"X-Accelerator-Marker" not in bytes(outputpo)
+        assert b"X-Merge-On" not in bytes(outputpo)
 
     def test_gaia_plurals(self):
         """Test conversion of gaia plural units."""
