@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
@@ -40,4 +39,6 @@ class ur(common.Common):
         #u"%": u"٪",
     }
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        'all': ["simplecaps", "startcaps"],
+    }
