@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2002-2006 Zuza Software Foundation
@@ -22,10 +21,10 @@
 or entire files (csvfile) for use with localisation
 """
 
-import codecs
 import csv
-from cStringIO import StringIO
+import six
 
+from translate.misc import csv_utils
 from translate.misc import sparse
 from translate.storage import base
 
@@ -97,13 +96,14 @@ class DefaultDialect(csv.excel):
     quoting = csv.QUOTE_NONNUMERIC
     escapechar = '\\'
 
+
 csv.register_dialect('default', DefaultDialect)
 
 
 def from_unicode(text, encoding='utf-8'):
     if encoding == 'auto':
         encoding = 'utf-8'
-    if isinstance(text, unicode):
+    if isinstance(text, six.text_type):
         return text.encode(encoding)
     return text
 
@@ -111,11 +111,12 @@ def from_unicode(text, encoding='utf-8'):
 def to_unicode(text, encoding='utf-8'):
     if encoding == 'auto':
         encoding = 'utf-8'
-    if isinstance(text, unicode):
+    if isinstance(text, six.text_type):
         return text
     return text.decode(encoding)
 
 
+@six.python_2_unicode_compatible
 class csvunit(base.TranslationUnit):
     spreadsheetescapes = [("+", "\\+"), ("-", "\\-"), ("=", "\\="), ("'", "\\'")]
 
@@ -206,7 +207,7 @@ class csvunit(base.TranslationUnit):
     def match_header(self):
         """see if unit might be a header"""
         some_value = False
-        for key, value in self.todict().iteritems():
+        for key, value in six.iteritems(self.todict()):
             if value:
                 some_value = True
             if key.lower() != 'fuzzy' and value and key.lower() != value.lower():
@@ -232,7 +233,7 @@ class csvunit(base.TranslationUnit):
         return source, target
 
     def fromdict(self, cedict, encoding='utf-8'):
-        for key, value in cedict.iteritems():
+        for key, value in six.iteritems(cedict):
             rkey = fieldname_map.get(key, key)
             if value is None or key is None or key == EXTRA_KEY:
                 continue
@@ -256,20 +257,20 @@ class csvunit(base.TranslationUnit):
 
         #self.source, self.target = self.remove_spreadsheet_escapes(self.source, self.target)
 
-    def todict(self, encoding='utf-8'):
+    def todict(self, **kwargs):
         #FIXME: use apis?
         #source, target = self.add_spreadsheet_escapes(self.source, self.target)
         source = self.source
         target = self.target
         output = {
-            'location': from_unicode(self.location, encoding),
-            'source': from_unicode(source, encoding),
-            'target': from_unicode(target, encoding),
-            'id': from_unicode(self.id, encoding),
+            'location': self.location,
+            'source': source,
+            'target': target,
+            'id': self.id,
             'fuzzy': str(self.fuzzy),
-            'context': from_unicode(self.context, encoding),
-            'translator_comments': from_unicode(self.translator_comments, encoding),
-            'developer_comments': from_unicode(self.developer_comments, encoding),
+            'context': self.context,
+            'translator_comments': self.translator_comments,
+            'developer_comments': self.developer_comments,
         }
 
         return output
@@ -277,7 +278,7 @@ class csvunit(base.TranslationUnit):
     def __str__(self):
         return str(self.todict())
 
-canonical_field_names = ('location', 'source', 'target', 'id', 'fuzzy', 'context', 'translator_comments', 'developer_comments')
+
 fieldname_map = {
     'original': 'source',
     'untranslated': 'source',
@@ -286,7 +287,7 @@ fieldname_map = {
     'identified': 'id',
     'key': 'id',
     'label': 'id',
-    'transaltor comments': 'translator_comments',
+    'translator comments': 'translator_comments',
     'notes': 'translator_comments',
     'developer comments': 'developer_comments',
     'state': 'fuzzy',
@@ -312,9 +313,11 @@ def try_dialects(inputfile, fieldnames, dialect):
 
 
 def valid_fieldnames(fieldnames):
-    """check if fieldnames are valid"""
+    """Check if fieldnames are valid, that is at least one field is identified
+    as the source.
+    """
     for fieldname in fieldnames:
-        if fieldname in canonical_field_names and fieldname == 'source':
+        if fieldname == 'source':
             return True
         elif fieldname in fieldname_map and fieldname_map[fieldname] == 'source':
             return True
@@ -323,7 +326,7 @@ def valid_fieldnames(fieldnames):
 
 def detect_header(sample, dialect, fieldnames):
     """Test if file has a header or not, also returns number of columns in first row"""
-    inputfile = StringIO(sample)
+    inputfile = csv.StringIO(sample)
     try:
         reader = csv.reader(inputfile, dialect)
     except csv.Error:
@@ -334,7 +337,7 @@ def detect_header(sample, dialect, fieldnames):
             inputfile.seek(0)
             reader = csv.reader(inputfile, 'excel')
 
-    header = reader.next()
+    header = next(reader)
     columncount = max(len(header), 3)
     if valid_fieldnames(header):
         return header
@@ -342,21 +345,21 @@ def detect_header(sample, dialect, fieldnames):
 
 
 class csvfile(base.TranslationStore):
-    """This class represents a .csv file with various lines.
-    The default format contains three columns: location, source, target"""
+    """This class represents a .csv file with various lines.  The default
+    format contains three columns: location, source, target
+    """
+
     UnitClass = csvunit
     Name = "Comma Separated Value"
     Mimetypes = ['text/comma-separated-values', 'text/csv']
     Extensions = ["csv"]
 
-    def __init__(self, inputfile=None, fieldnames=None, encoding="auto"):
-        base.TranslationStore.__init__(self, unitclass=self.UnitClass)
-        self.units = []
-        self.encoding = encoding or 'utf-8'
+    def __init__(self, inputfile=None, fieldnames=None, encoding='auto'):
+        super(csvfile, self).__init__(encoding=encoding)
         if not fieldnames:
             self.fieldnames = ['location', 'source', 'target', 'id', 'fuzzy', 'context', 'translator_comments', 'developer_comments']
         else:
-            if isinstance(fieldnames, basestring):
+            if isinstance(fieldnames, six.string_types):
                 fieldnames = [fieldname.strip() for fieldname in fieldnames.split(",")]
             self.fieldnames = fieldnames
         self.filename = getattr(inputfile, 'name', '')
@@ -369,15 +372,14 @@ class csvfile(base.TranslationStore):
     def parse(self, csvsrc):
         text, encoding = self.detect_encoding(csvsrc, default_encodings=['utf-8', 'utf-16'])
         #FIXME: raise parse error if encoding detection fails?
-        if encoding and encoding.lower() != 'utf-8':
-            csvsrc = text.encode('utf-8').lstrip(codecs.BOM_UTF8)
         self.encoding = encoding or 'utf-8'
 
         sniffer = csv.Sniffer()
-        # FIXME: maybe we should sniff a smaller sample
-        sample = csvsrc[:1024]
-        if isinstance(sample, unicode):
-            sample = sample.encode('utf-8')
+        # sniff and detect_header want bytes on Python 2 but text on Python 3
+        if six.PY2:
+            sample = csvsrc[:1024]
+        else:
+            sample = text[:1024]
 
         try:
             self.dialect = sniffer.sniff(sample)
@@ -396,7 +398,7 @@ class csvfile(base.TranslationStore):
         except csv.Error:
             pass
 
-        inputfile = csv.StringIO(csvsrc)
+        inputfile = csv.StringIO(csvsrc if six.PY2 else text)
         reader = try_dialects(inputfile, self.fieldnames, self.dialect)
 
         #reader = SimpleDictReader(csvfile, fieldnames=fieldnames, dialect=dialect)
@@ -408,24 +410,21 @@ class csvfile(base.TranslationStore):
                 self.addunit(newce)
             first_row = False
 
-    def __str__(self):
-        """convert to a string. double check that unicode is handled somehow here"""
+    def serialize(self, out):
+        """Write to file"""
         source = self.getoutput()
-        if not isinstance(source, unicode):
+        if not isinstance(source, six.text_type):
             source = source.decode('utf-8')
-        if not self.encoding or self.encoding == 'auto':
-            encoding = 'utf-8'
-        else:
-            encoding = self.encoding
-        return source.encode(encoding)
+        out.write(source.encode(self.encoding))
 
     def getoutput(self):
-        outputfile = StringIO()
-        writer = csv.DictWriter(outputfile, self.fieldnames, extrasaction='ignore', dialect=self.dialect)
-        # write header
-        hdict = dict(map(None, self.fieldnames, self.fieldnames))
-        writer.writerow(hdict)
+        output = csv.StringIO()
+        writer = csv_utils.UnicodeDictWriter(output, self.fieldnames,
+                                             encoding=self.encoding,
+                                             extrasaction='ignore',
+                                             dialect=self.dialect)
+        # writeheader() would need Python 2.7
+        writer.writerow(dict(zip(self.fieldnames, self.fieldnames)))
         for ce in self.units:
-            cedict = ce.todict()
-            writer.writerow(cedict)
-        return outputfile.getvalue()
+            writer.writerow(ce.todict())
+        return output.getvalue()
