@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2007-2010 Zuza Software Foundation
@@ -26,11 +25,11 @@
 import logging
 import os.path
 import re
+import six
 import stat
 import sys
-import thread
+from six.moves import _thread, UserDict
 from sqlite3 import dbapi2
-from UserDict import UserDict
 
 from translate import __version__ as toolkitversion
 from translate.lang.common import Common
@@ -87,7 +86,8 @@ def wordcount(string):
 
 def wordsinunit(unit):
     """Counts the words in the unit's source and target, taking plurals into
-    account. The target words are only counted if the unit is translated."""
+    account. The target words are only counted if the unit is translated.
+    """
     (sourcewords, targetwords) = (0, 0)
     if isinstance(unit.source, multistring):
         sourcestrings = unit.source.strings
@@ -212,12 +212,12 @@ class FileTotals(object):
 
     @classmethod
     def _compute_derived_values(cls, record):
-        record["total"] = record["untranslated"] + \
-                          record["translated"] + \
-                          record["fuzzy"]
-        record["totalsourcewords"] = record["untranslatedsourcewords"] + \
-                                     record["translatedsourcewords"] + \
-                                     record["fuzzysourcewords"]
+        record["total"] = (record["untranslated"] +
+                           record["translated"] +
+                           record["fuzzy"])
+        record["totalsourcewords"] = (record["untranslatedsourcewords"] +
+                                      record["translatedsourcewords"] +
+                                      record["fuzzysourcewords"])
         record["review"] = 0
 
     def __getitem__(self, fileid):
@@ -282,7 +282,9 @@ def suggestion_filename(filename):
 # ALL PUBLICLY ACCESSIBLE METHODS MUST BE DECORATED WITH THE transaction DECORATOR.
 class StatsCache(object):
     """An object instantiated as a singleton for each statsfile that provides
-    access to the database cache from a pool of StatsCache objects."""
+    access to the database cache from a pool of StatsCache objects.
+    """
+
     _caches = {}
     defaultfile = None
     con = None
@@ -291,13 +293,13 @@ class StatsCache(object):
     """The current cursor"""
 
     def __new__(cls, statsfile=None):
-        current_thread = thread.get_ident()
+        current_thread = _thread.get_ident()
 
         def make_database(statsfile):
 
             def connect(cache):
                 # sqlite needs to get the name in utf-8 on all platforms
-                cache.con = dbapi2.connect(statsfile.encode('utf-8'))
+                cache.con = dbapi2.connect(statsfile.encode('utf-8') if six.PY2 else statsfile)
                 cache.cur = cache.con.cursor()
 
             def clear_old_data(cache):
@@ -332,7 +334,8 @@ class StatsCache(object):
                     cachedir = os.path.join(userdir, ".translate_toolkit")
                 if not os.path.exists(cachedir):
                     os.mkdir(cachedir)
-                cachedir = cachedir.decode(sys.getfilesystemencoding())
+                if isinstance(cachedir, bytes):
+                    cachedir = six.text_type(cachedir, sys.getfilesystemencoding())
                 cls.defaultfile = os.path.realpath(os.path.join(cachedir, u"stats.db"))
             statsfile = cls.defaultfile
         else:
@@ -403,8 +406,8 @@ class StatsCache(object):
 
         store can be a TranslationFile object or a callback that returns one.
         """
-        if isinstance(filename, str):
-            filename = unicode(filename, sys.getfilesystemencoding())
+        if isinstance(filename, bytes):
+            filename = six.text_type(filename, sys.getfilesystemencoding())
         realpath = os.path.realpath(filename)
         self.cur.execute("""SELECT fileid, st_mtime, st_size FROM files
                 WHERE path=?;""", (realpath,))
@@ -458,7 +461,8 @@ class StatsCache(object):
                                    unit.get_state_id()))
                 file_totals_record = file_totals_record + FileTotals.new_record(unit_state_for_db, sourcewords, targetwords)
         # XXX: executemany is non-standard
-        self.cur.executemany("""INSERT INTO units
+        self.cur.executemany(
+            """INSERT INTO units
             (unitid, fileid, unitindex, source, target, sourcewords, targetwords, state, e_state)
             values (?, ?, ?, ?, ?, ?, ?, ?, ?);""",
             unitvalues)
@@ -470,10 +474,12 @@ class StatsCache(object):
     @transaction
     def _cachestore(self, store, realpath, mod_info):
         """Calculates and caches the statistics of the given store
-        unconditionally."""
+        unconditionally.
+        """
         self.cur.execute("""DELETE FROM files WHERE
             path=?;""", (realpath,))
-        self.cur.execute("""iNSERT INTO files
+        self.cur.execute(
+            """INSERT INTO files
             (fileid, path, st_mtime, st_size, toolkitbuild) values (NULL, ?, ?, ?, ?);""",
             (realpath, mod_info[0], mod_info[1], toolkitversion.build))
         # Unusual capitalisation intended. See bug 2073.
@@ -501,7 +507,8 @@ class StatsCache(object):
 
     def filetotals(self, filename, store=None, extended=False):
         """Retrieves the statistics for the given file if possible, otherwise
-        delegates to cachestore()."""
+        delegates to cachestore().
+        """
         stats = self.file_totals[self._getfileid(filename, store=store)]
         if extended:
             stats["extended"] = self.file_extended_totals(filename, store=store)
@@ -522,7 +529,7 @@ class StatsCache(object):
                 if unitindex:
                     index = unitindex
                 failures = checker.run_filters(unit)
-                for checkname, checkmessage in failures.iteritems():
+                for checkname, checkmessage in six.iteritems(failures):
                     unitvalues.append((index, fileid, configid, checkname, checkmessage))
                     errornames.append("check-" + checkname)
         checker.setsuggestionstore(None)
@@ -534,16 +541,17 @@ class StatsCache(object):
             errornames.append("total")
 
         # XXX: executemany is non-standard
-        self.cur.executemany("""INSERT INTO uniterrors
-            (unitindex, fileid, configid, name, message)
-            values (?, ?, ?, ?, ?);""",
-            unitvalues)
+        self.cur.executemany(
+            "INSERT INTO uniterrors "
+            "(unitindex, fileid, configid, name, message) "
+            "values (?, ?, ?, ?, ?);", unitvalues)
         return errornames
 
     @transaction
     def _cachestorechecks(self, fileid, store, checker, configid):
         """Calculates and caches the error statistics of the given store
-        unconditionally."""
+        unconditionally.
+        """
         # Let's purge all previous failures because they will probably just
         # fill up the database without much use.
         self.cur.execute("""DELETE FROM uniterrors WHERE
@@ -576,13 +584,15 @@ class StatsCache(object):
         for example.
 
         This method assumes that everything was up to date before (file totals,
-        checks, checker config, etc."""
+        checks, checker config, etc.
+        """
         fileid = self._getfileid(filename, check_mod_info=False)
         configid = self._get_config_id(fileid, checker)
         unitid = unit.getid()
         # get the unit index
-        totals_without_unit = self.file_totals[fileid] - \
-                                   FileTotals.new_record(*self.get_unit_stats(fileid, unitid))
+        totals_without_unit = (self.file_totals[fileid] -
+                               FileTotals.new_record(*self.get_unit_stats(fileid,
+                                                                          unitid)))
         self.cur.execute("""SELECT unitindex FROM units WHERE
             fileid=? AND unitid=?;""", (fileid, unitid))
         unitindex = self.cur.fetchone()[0]
@@ -635,15 +645,17 @@ class StatsCache(object):
         configid = self._getstoredcheckerconfig(checker)
         if configid:
             return configid
-        self.cur.execute("""iNSERT INTO checkerconfigs
-            (configid, config) values (NULL, ?);""",
+        self.cur.execute(
+            "INSERT INTO checkerconfigs "
+            "(configid, config) values (NULL, ?);",
             (str(checker.config.__dict__),))
         # Unusual capitalisation intended. See bug 2073.
         return self.cur.lastrowid
 
     def filechecks(self, filename, checker, store=None):
         """Retrieves the error statistics for the given file if possible,
-        otherwise delegates to cachestorechecks()."""
+        otherwise delegates to cachestorechecks().
+        """
         fileid = self._getfileid(filename, store=store)
         configid = self._get_config_id(fileid, checker)
         values = self._geterrors(filename, fileid, configid, checker, store)
@@ -653,7 +665,7 @@ class StatsCache(object):
             if value[1] == -1:
                 continue
             checkkey = 'check-' + value[0]      # value[0] is the error name
-            if not checkkey in errors:
+            if checkkey not in errors:
                 errors[checkkey] = []
             errors[checkkey].append(value[1])   # value[1] is the unitindex
 
@@ -671,8 +683,9 @@ class StatsCache(object):
         return self.cur.fetchone() is not None
 
     def filestatestats(self, filename, store=None, extended=False):
-        """Return a dictionary of unit stats mapping sets of unit
-        indices with those states"""
+        """Return a dictionary of unit stats mapping sets of unit indices with
+        those states
+        """
         stats = emptyfilestats()
         if extended:
             stats["extended"] = {}
@@ -693,8 +706,9 @@ class StatsCache(object):
         return stats
 
     def filestats(self, filename, checker, store=None, extended=False):
-        """Return a dictionary of property names mapping sets of unit
-        indices with those properties."""
+        """Return a dictionary of property names mapping sets of unit indices
+        with those properties.
+        """
         stats = emptyfilestats()
         stats.update(self.filechecks(filename, checker, store))
         stats.update(self.filestatestats(filename, store, extended=extended))
@@ -704,12 +718,13 @@ class StatsCache(object):
         # For now, lang and store are unused. lang will allow the user to
         # base stats information on the given language. See the commented
         # line containing stats.update below.
-        """Return a dictionary of property names mapping to arrays which
-        map unit indices to property values.
+        """Return a dictionary of property names mapping to arrays which map
+        unit indices to property values.
 
         Please note that this is different from filestats, since filestats
         supplies sets of unit indices with a given property, whereas this
-        method supplies arrays which map unit indices to given values."""
+        method supplies arrays which map unit indices to given values.
+        """
         stats = emptyunitstats()
 
         #stats.update(self.unitchecks(filename, lang, store))
