@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
 # Copyright 2005, 2006 Zuza Software Foundation
@@ -74,17 +74,16 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
             else:
                 inputfiles = [options.input]
         self.textmap = {}
-        self.initprogressbar(inputfiles, options)
+        progress_bar = optrecurse.ProgressBar(options.progress, inputfiles)
         for inputpath in inputfiles:
             fullinputpath = self.getfullinputpath(options, inputpath)
             try:
                 success = self.processfile(options, fullinputpath)
-            except Exception as error:
-                if isinstance(error, KeyboardInterrupt):
-                    raise self.warning("Error processing: input %s" % (fullinputpath), options, sys.exc_info())
+            except Exception:
+                self.warning("Error processing: input %s" % (fullinputpath), options, sys.exc_info())
                 success = False
-            self.reportprogress(inputpath, success)
-        del self.progressbar
+            progress_bar.report_progress(inputpath, success)
+        del progress_bar
 
     def processfile(self, options, fullinputpath):
         """process an individual file"""
@@ -102,13 +101,13 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
                     self.checkoutputsubdir(options, os.path.dirname(outputpath))
                     fulloutputpath = os.path.join(options.output, outputpath)
                     if os.path.isfile(fulloutputpath):
-                        outputfile = open(fulloutputpath, 'r')
+                        outputfile = open(fulloutputpath, 'rb')
                         outputpofile = po.pofile(outputfile)
                     else:
                         outputpofile = po.pofile()
                     outputpofile.units.append(pounit)   # TODO:perhaps check to see if it's already there...
-                    outputfile = open(fulloutputpath, 'w')
-                    outputfile.write(str(outputpofile))
+                    with open(fulloutputpath, 'wb') as fh:
+                        outputpofile.serialize(fh)
 
 
 def main():
